@@ -5,24 +5,23 @@
 #include <qhbox.h>
 #include <qvbox.h>
 #include <qlayout.h>
+#include <qcolor.h>
 
 
 TTip::TTip(QWidget* parent, const char* name) : QWidget (0,"TTIP",WX11BypassWM)
 {
 	
 	setBackgroundMode(NoBackground);
-	//resize(200,100);
-	//show();
-//QHBox *h = new QHBox(this);
 	
+	QHBoxLayout *h = new QHBoxLayout(this,10,5);
+	h->setAutoAdd(true);
+
 	m_view = new InfoPopup(this);
-	QGridLayout *grid = new QGridLayout( this, 2, 2, 10, 10, "Layout"); 
-	grid->addWidget( m_view, 1, 1 );
-    	
-
-    	resize( QSize(186, 62).expandedTo(minimumSizeHint()) );
+	
+	
+	m_view->adjustSize();
+	adjustSize();
 	clearWState( WState_Polished );
-
 }
 TTip::~TTip()
 {
@@ -34,10 +33,14 @@ void TTip::updateTip( const QString & e, double speed, const QString& lbl)
 }
 void TTip::drawIt(QPainter *p)
 {
-    //QBrush b1( Qt::blue );
 
-    QBrush b2( paletteBackgroundColor() );//, Qt::Dense6Pattern );          // green 12% fill
-    //QBrush b3( Qt::NoBrush );                           // void brush
+	p->fillRect(0,0,width(),height(),backgroundBrush ());
+
+    QBrush b2( m_view->paletteBackgroundColor() );//, Qt::Dense6Pattern );          // green 12% fill
+//     QBrush b3( Qt::NoBrush );                           // void brush
+// 	p->setBrush(b3);
+// 	p->clearRect(0,0,width(),height());
+
     //QBrush b4( Qt::CrossPattern );                      // black cross pattern
    
     p->setBrush( b2 );
@@ -48,5 +51,25 @@ void TTip::paintEvent(QPaintEvent *e)
 {
 	QPainter p(this);
 	drawIt(&p);
-	
 }
+
+void TTip::fontChange(const QFont & f)
+{
+	m_view->adjustSize();
+	adjustSize();
+}
+void TTip::paletteChange( const QPalette & oldPalette )
+{
+	m_view->adjustSize();
+	adjustSize();
+	
+	setPalette(m_view->palette());
+	repaint();
+}
+void TTip::styleChange( const QStyle & oldStyle )
+{
+	m_view->adjustSize();
+	adjustSize();
+	setStyle(&m_view->style());
+	repaint();
+}
\ No newline at end of file
