@@ -5,6 +5,9 @@
 #include <qpixmap.h>
 #include <passivepopup.h>
 #include <qpopupmenu.h>
+#include <qfont.h>
+#include <qstyle.h>
+#include <qpalette.h>
 
 class TTip : public QWidget
 {
@@ -18,6 +21,10 @@ private:
 void drawIt(QPainter *p);
 protected:
 void paintEvent(QPaintEvent *e);
+virtual void fontChange(const QFont &f);
+virtual void styleChange(const QStyle &s);
+virtual void paletteChange(const QPalette &p);
+
 QPixmap *buf;
 InfoPopup *m_view;
 
