@@ -30,10 +30,17 @@
 #include <unistd.h>
 
 #include "mydock.h"
+#include <qtabwidget.h>
+
 
 int a;
 int b;
 
+
+/**
+ * 
+ * @return 
+ */
 mydock::mydock() : KSystemTray()
 {
 	
@@ -53,8 +60,16 @@ mydock::mydock() : KSystemTray()
 	connect(netset->cboDevices,SIGNAL(activated(const QString&)),this,SLOT(setIface(const QString&)));
 	connect(netset->cboDevices,SIGNAL(activated(const QString&)),this,SLOT(saveState()));
 
+	tipEnabled=true;
+
+	contextMenu()->setCheckable(true);
+	int m_id = contextMenu()->insertItem( "&Details",  this, SLOT(showSettings()) );
+	contextMenu()->insertSeparator(m_id);
+
+	tipMenuID = contextMenu()->insertItem( "Disable &Tooltip",  this, SLOT(disableTip()) );
+	contextMenu()->setItemChecked(tipMenuID,!tipEnabled);
+	
 	
-	contextMenu()->insertItem( "&Settings",  this, SLOT(showSettings()) );
 	nlsock=0;
 	fdsock=0;
 	stats = new iw_statistics;
@@ -93,7 +108,12 @@ int mydock::getAhead()
 {
 return a;
 }
-
+void mydock::disableTip()
+{
+	tipEnabled=!tipEnabled;
+	contextMenu()->setItemChecked(tipMenuID,!tipEnabled);
+	saveState(); 
+}
 void mydock::enterEvent(QEvent *e)
 {
 /*
@@ -101,6 +121,8 @@ void mydock::enterEvent(QEvent *e)
         int graby = mapToGlobal(e->pos()).y();
 	popup->move(grabx,graby);
 */
+if (tipEnabled)
+{
 	if (popup->isShown() || contextMenu()->isShown() || netset->isShown())return;
 	QPoint loc = mapToGlobal(mapFromParent(QPoint(0,0)));
 	QPoint np = QPoint(loc.x()-popup->width(),loc.y()-popup->height());
@@ -114,7 +136,7 @@ void mydock::enterEvent(QEvent *e)
 	}
 	popup->move(np);
 	popup->show();
-
+}
 }
 void mydock::mouseEnterEvent(QMouseEvent *e)
 {
@@ -137,6 +159,7 @@ void mydock::saveState()
 	cfg->setGroup("Interface"+QString("%1").arg(r_index));
 	cfg->writeEntry("name",netset->cboDevices->currentText());
 	cfg->writeEntry("index",netset->cboDevices->currentItem());
+	cfg->writeEntry("tipEnabled",tipEnabled);
 	cfg->setGroup("Instances");
 	cfg->writeEntry("number",a-b);
 	
@@ -149,10 +172,15 @@ void mydock::start()
 	cfg->setGroup("Interface"+QString("%1").arg(r_index));
 	int sel_index=cfg->readNumEntry("index",0);
 	QString sel_name=cfg->readEntry("name","lo");
+	bool tip=cfg->readBoolEntry("tipEnabled",true);
+	
 	netset->cboDevices->setCurrentItem(sel_index);
 	setIface(sel_name);
 	saveState();
-	
+	if (!tip)
+	{
+		disableTip();
+	}
 }
 
 void mydock::paintEvent (QPaintEvent *)
@@ -167,11 +195,11 @@ void mydock::paintEvent (QPaintEvent *)
 		break;
     case 1: 
 		qpainter.drawPixmap (0, 0, UserIcon("off"));
-		qpainter.drawPixmap (7, 2, UserIcon("ifled"));	
+		qpainter.drawPixmap (7, 14, UserIcon("ifled"));	
 		break;
     case 2:
 		qpainter.drawPixmap (0, 0, UserIcon("off"));
-		qpainter.drawPixmap (7, 14, UserIcon("ifled"));	
+		qpainter.drawPixmap (7, 2, UserIcon("ifled"));	
 		break;
     case 3:
 	qpainter.drawPixmap (0, 0, UserIcon("off"));
@@ -345,6 +373,7 @@ bool mydock::queryDevices()
 	}
 	return true;
 }
+
 void mydock::disableDevice()
 {
 	updateTip(if_name + "\nUnable to qurey device");
@@ -369,7 +398,7 @@ void mydock::update()
 	allifs[v].wstat->link_qual=0;
 	allifs[v].wstat->noise_level=0;
 	allifs[v].wstat->signal_level=0;	
-	netset->frmWrl->setEnabled(false);
+	
 	
     if (if_name =="")
     {
@@ -471,6 +500,7 @@ void mydock::update()
 							.arg(hw[3],2,16)
 							.arg(hw[4],2,16)
 							.arg(hw[5],2,16);
+					mac.replace(' ', '0');
 					allifs[v].addrstat->mac=mac;
 				}
 				emit updateInfo(allifs[v].addrstat);
@@ -478,6 +508,13 @@ void mydock::update()
 
 				if (allifs[v].wr)
 				{
+
+					bool enb = netset->tabs->isTabEnabled(netset->WifiStats);
+					if (!enb)
+					{
+						netset->tabs->setTabEnabled(netset->WifiStats,true);
+					}
+
 					struct iwreq wireq;
 					struct iw_range *range;
 
@@ -499,8 +536,9 @@ void mydock::update()
 						allifs[v].wstat->noise_level=stats->qual.noise;
 						allifs[v].wstat->signal_level=stats->qual.level;	
 						
-						netset->frmWrl->setEnabled(true);
-						
+						//netset->frmWrl->setEnabled(true);
+						//netset->tabs->setTabEnabled(netset->WifiStats,true);
+
 						memset(rngbuf, 0, sizeof(rngbuf));
 						
 						wireq.u.data.pointer = (caddr_t) rngbuf;
@@ -530,11 +568,15 @@ void mydock::update()
 						}
 					}
 					
-
+					emit updateWiFi(allifs[v].wstat);
+					essid = allifs[v].wstat->essid;
+				}
+				else
+				{
+ 					netset->tabs->setTabEnabled(netset->WifiStats,false);
+					
 				}
 				
-				emit updateWiFi(allifs[v].wstat);
-				essid = allifs[v].wstat->essid;
 				break;
 			}
 		
@@ -654,7 +696,7 @@ void mydock::update()
 							emit updateStats(stats, allifs[v].total);
 							QString c="";
 							
-							QString str = "\nMonitoring: " + if_name;
+							QString str = "Monitoring: " + if_name;
 								str += QString("\nRX Bytes: %1").arg(netset->getScaleString(allifs[v].total->bytes_in,&c),0,'f',2)+c;
 								str += QString("\nTX Bytes: %1").arg(netset->getScaleString(allifs[v].total->bytes_out,&c),0,'f',2)+c;
 							if (allifs[v].wr)
