@@ -34,7 +34,6 @@
 #include "TTip.h"
 
 
-
 /**
 @author yodor
 */
@@ -59,6 +58,7 @@ public slots:
 	void saveState();
 	void setIface(const QString&);
         void hideInstance();
+	void disableTip();
 
 int getBack();
 int getAhead();
@@ -72,7 +72,10 @@ protected:
 	virtual void enterEvent(QEvent *);
 	virtual void leaveEvent(QEvent *);
 	virtual void mouseEnterEvent(QMouseEvent *e);
-	
+	KNetDockIf *allifs;
+	int readSock(int sockFd, char *bufPtr, int seqNum, int pId);
+	void updateTip(const QString& tip,double speed=0, const QString& lbl = "");
+	void updateDockIcon(int mode);
 
 signals:
 	void ifacechange();
@@ -82,21 +85,23 @@ signals:
 	
 
 private:
+	int tipMenuID;
+	bool tipEnabled;
+
 	QString if_name;
 	NetSettingsDialog *netset;
 	QTimer *ifupdater;
 	
-	KNetDockIf *allifs;
+	
 
 	int c_icon;
 	int msgSeq;
 	int nlsock;
 	int fdsock;
 
-	void updateTip(const QString& tip,double speed=0, const QString& lbl = "");
-	void updateDockIcon(int mode);
+	
 	void disableDevice();
-	int readSock(int sockFd, char *bufPtr, int seqNum, int pId);	
+		
 
 	iw_statistics *stats;
 	char msgBuf[NL_BUFSIZE];
