@@ -58,9 +58,9 @@ void NetSettingsDialog::resizeEvent(QResizeEvent *e)
 	int nw = chartframe->width();
 	cframe->setGeometry(0,0,nw,chartframe->height());
 	
-	//cframe->init();
+	
 cframe->resize(nw);
-	//cframe->clearChart();
+	
 }
 
 void NetSettingsDialog::updateInfo(const AddrStat *astat)
@@ -197,5 +197,25 @@ bool NetSettingsDialog::eventFilter(QObject *,QEvent *)
     }
 }
 
-
+void NetSettingsDialog::fontChange(const QFont & f)
+{
+	
+	adjustSize();
+	repaint();
+}
+void NetSettingsDialog::paletteChange( const QPalette & oldPalette )
+{
+	
+	adjustSize();
+	
+	setPalette(palette());
+	repaint();
+}
+void NetSettingsDialog::styleChange( const QStyle & oldStyle )
+{
+	
+	adjustSize();
+	
+	repaint();
+}
 #include "netsettingsdialog.moc"
