@@ -10,14 +10,9 @@
 ** destructor.
 *****************************************************************************/
 
-
 void InfoPopup::updateTip( const QString & e, double speed, const QString& lbl)
 {
     lblMonitor->setText(e);
-    if (lbl=="" && speed==0)
-    {
-	frmSpeed->hide();
-    }
     lcdSpeed->display(speed);
     lblSpeed->setText(lbl+" B/s");
 }
